@@ -50,7 +50,7 @@ class TrocketClient(AbstractClient):
 
 
     def CreateInstance(self, request):
-        """购买新实例
+        """创建 RocketMQ 5.x 集群
 
         :param request: Request instance for CreateInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.CreateInstanceRequest`
@@ -280,7 +280,7 @@ class TrocketClient(AbstractClient):
 
 
     def DeleteMQTTInstance(self, request):
-        """删除实例
+        """删除MQTT实例
 
         :param request: Request instance for DeleteMQTTInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DeleteMQTTInstanceRequest`
@@ -303,7 +303,7 @@ class TrocketClient(AbstractClient):
 
 
     def DeleteMQTTTopic(self, request):
-        """删除主题
+        """删除MQTT主题
 
         :param request: Request instance for DeleteMQTTTopic.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DeleteMQTTTopicRequest`
@@ -686,7 +686,7 @@ class TrocketClient(AbstractClient):
 
 
     def DescribeMQTTProductSKUList(self, request):
-        """非对外接口，获取产品售卖规格
+        """获取产品售卖规格
 
         :param request: Request instance for DescribeMQTTProductSKUList.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeMQTTProductSKUListRequest`
@@ -858,29 +858,6 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeTopicStatsOp(self, request):
-        """运营端查询topicStata
-
-        :param request: Request instance for DescribeTopicStatsOp.
-        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeTopicStatsOpRequest`
-        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeTopicStatsOpResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeTopicStatsOp", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeTopicStatsOpResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def ImportSourceClusterConsumerGroups(self, request):
         """导入消费者组列表
 
@@ -974,7 +951,7 @@ class TrocketClient(AbstractClient):
 
 
     def ModifyMQTTInsPublicEndpoint(self, request):
-        """为MQTT实例创建公网接入点
+        """更新MQTT实例公网接入点
 
         :param request: Request instance for ModifyMQTTInsPublicEndpoint.
         :type request: :class:`tencentcloud.trocket.v20230308.models.ModifyMQTTInsPublicEndpointRequest`
